@@ -5,22 +5,22 @@ GITREF=`git rev-parse --short HEAD`
 
 if [[ -z ${BRANCH} ]]; then
   BRANCH=`git name-rev $GITREF --name-only`
-else
-  printf "Using environment set variable BRANCH=%s\n" "${BRANCH}"
 fi
 
 if [[ $BRANCH =~ ^(tags/)?(v)[.0-9]+(-(rc)?([0-9]+))?$ ]]; then
   BUILD="rc"
+elif [[ ! -z ${DMC_REPO_BRANCH} ]]; then
+  BUILD="${DMC_REPO_BRANCH}"
 else
-  BUILD="${BRANCH}"
+  BUILD="develop"
 fi
 
 DIST=$(rpm --eval "%{dist}" | cut -d. -f2)
 DISTNAME=${DIST}
 
 # Special handling of FC rawhide
-[[ "${DISTNAME}" == "fc35" ]] && DISTNAME="fc-rawhide"
-[[ "${DISTNAME}" == "fc36" ]] && DISTNAME="fc-rawhide"
+[[ "${DISTNAME}" == "fc38" ]] && DISTNAME="fc-rawhide"
+[[ "${DISTNAME}" == "fc39" ]] && DISTNAME="fc-rawhide"
 
 if [[ ${BUILD} == "rc" ]]; then
 	REPO_PATH="${BUILD}/${DISTNAME}/\$basearch"
@@ -30,7 +30,6 @@ else
 	REPO_PATH="testing/${BUILD}/${DISTNAME}/\$basearch"
 fi
 
-echo "Installing /etc/yum.repo.d/dmc-${BUILD}-${DISTNAME}.repo"
 cat <<- EOF > "/etc/yum.repos.d/dmc-${BUILD}-${DISTNAME}.repo"
 	[dmc-${BUILD}-${DISTNAME}]
 	name=DMC Repository
@@ -40,3 +39,5 @@ cat <<- EOF > "/etc/yum.repos.d/dmc-${BUILD}-${DISTNAME}.repo"
 	protect=0
 	priority=3
 	EOF
+
+echo "dmc-${BUILD}-${DISTNAME}.repo"
